@@ -181,6 +181,8 @@ void context_model_table::decouple_or_alloc_with_empty_data()
   if (D) printf("%p (alloc)\n",this);
 
   model = new context_model[CONTEXT_MODEL_TABLE_LENGTH];
+  // Without initializing the model, we got an invalid model state during decoding (issue #236)
+  memset(model, 0, sizeof(context_model) * CONTEXT_MODEL_TABLE_LENGTH);
   refcnt= new int;
   *refcnt=1;
 }
