@@ -126,6 +126,11 @@ void logdebug(enum LogModule module, const char* string, ...)
   va_end(va);
   fflush(stdout);
 }
+
+bool logdebug_enabled(enum LogModule module)
+{
+  return verbosity>=2;
+}
 #endif
 
 #ifdef DE265_LOG_TRACE
@@ -173,13 +178,14 @@ void log2fh(FILE* fh, const char* string, ...)
 
 
 
-void printBlk(const char* title, const int16_t* data, int blksize, int stride)
+void printBlk(const char* title, const int16_t* data, int blksize, int stride,
+              const std::string& prefix)
 {
-  printf("%s:\n",title);
+  if (title) printf("%s%s:\n",prefix.c_str(),title);
 
   for (int y=0;y<blksize;y++) {
     //logtrace(LogTransform,"  ");
-    printf("  ");
+    printf("%s",prefix.c_str());
     for (int x=0;x<blksize;x++) {
       //logtrace(LogTransform,"*%3d ", data[x+y*stride]);
       printf("%4d ", data[x+y*stride]);
@@ -190,13 +196,14 @@ void printBlk(const char* title, const int16_t* data, int blksize, int stride)
 }
 
 
-void printBlk(const char* title, const int32_t* data, int blksize, int stride)
+void printBlk(const char* title, const int32_t* data, int blksize, int stride,
+              const std::string& prefix)
 {
-  printf("%s:\n",title);
+  if (title) printf("%s%s:\n",prefix.c_str(),title);
 
   for (int y=0;y<blksize;y++) {
     //logtrace(LogTransform,"  ");
-    printf("  ");
+    printf("%s",prefix.c_str());
     for (int x=0;x<blksize;x++) {
       //logtrace(LogTransform,"*%3d ", data[x+y*stride]);
       printf("%4d ", data[x+y*stride]);
@@ -207,13 +214,14 @@ void printBlk(const char* title, const int32_t* data, int blksize, int stride)
 }
 
 
-void printBlk(const char* title, const uint8_t* data, int blksize, int stride)
+void printBlk(const char* title, const uint8_t* data, int blksize, int stride,
+              const std::string& prefix)
 {
-  printf("%s:\n",title);
+  if (title) printf("%s%s:\n",prefix.c_str(),title);
 
   for (int y=0;y<blksize;y++) {
     //logtrace(LogTransform,"  ");
-    printf("  ");
+    printf("%s",prefix.c_str());
     for (int x=0;x<blksize;x++) {
       //logtrace(LogTransform,"*%3d ", data[x+y*stride]);
       printf("%02x ", data[x+y*stride]);
